import greenfoot.*;  // imports Actor, World, Greenfoot, GreenfootImage
import java.awt.Color;
import java.util.Random;

/**
 * A world where wombats live.
 * 
 * @author Michael Kolling
 * @version 1.0.1
 */
public class WombatWorld extends World
{

    private Bug bug;
    private Scoreboard scores;

    /**
     * Create a new world with 8x8 cells and
     * with a cell size of 60x60 pixels
     */
    public WombatWorld() 
    {
        super(600, 600, 1);        
        setBackground("cell.jpg");
        this.populate();
        Greenfoot.setSpeed(58);
    }
    
    public void act()
    {
        if(Greenfoot.getRandomNumber(5000)==0){
            Pik pik = new Pik();
            int x = 15+Greenfoot.getRandomNumber(getWidth()-30);
            int y = 60+Greenfoot.getRandomNumber(getHeight()-75);
            addObject(pik, x, y);
        }
        
        if(getObjects(Bug.class).isEmpty()){
            Greenfoot.setSpeed(0);
        }
        
        if(getObjects(Leaf.class).isEmpty()){
            int level = scores.getLevel()+1;
            scores.setLevel(level);
            StatusUtil.setInvinc(bug, 300);
            if(level <= 5){
                randomLeafs(5);
                randomCrabs(1);
            }
            if(level > 5 && level <= 10){
                randomLeafs(5);
                randomBees(1);
                randomCrabs(1);
            }
            if(level > 10 && level <= 15){
                randomLeafs(5);
                randomBees(1);
                randomBumbles(1);
            }
            if(level > 15 && level <= 100){
                randomLeafs(5);
                randomBumbles(1);
                randomBadbugs(1);
            }
        }
    }
    
    /**
     * Populate the world with a fixed scenario of wombats and leaves.
     */    
    public void populate()
    {
        bug = new Bug();
        StatusUtil.setInvinc(bug, 300);
        addObject(bug, 100, 300);

        randomCrabs(2);
        randomLeafs(5);
        
        scores = new Scoreboard();
        scores.drawBoard();
        addObject(scores, 300, 30);
    }
    
    public void randomBadbugs(int howMany)
    {
        for(int i=0; i<howMany; i++) {
            Badbug b = new Badbug();
            int x = 15+Greenfoot.getRandomNumber(getWidth()-30);
            int y = 60+Greenfoot.getRandomNumber(getHeight()-75);
            addObject(b, x, y);
        }
    }
    
    public void randomBees(int howMany)
    {
        for(int i=0; i<howMany; i++) {
            Bee bee = new Bee();
            int x = 15+Greenfoot.getRandomNumber(getWidth()-30);
            int y = 60+Greenfoot.getRandomNumber(getHeight()-75);
            addObject(bee, x, y);
        }
    }
    
    public void randomBumbles(int howMany)
    {
        for(int i=0; i<howMany; i++) {
            Bumble b = new Bumble();
            int x = 15+Greenfoot.getRandomNumber(getWidth()-30);
            int y = 60+Greenfoot.getRandomNumber(getHeight()-75);
            addObject(b, x, y);
        }
    }
    
    public void randomCrabs(int howMany)
    {
        for(int i=0; i<howMany; i++) {
            Crab crab = new Crab();
            int x = 15+Greenfoot.getRandomNumber(getWidth()-30);
            int y = 60+Greenfoot.getRandomNumber(getHeight()-75);
            addObject(crab, x, y);
        }
    }
    
    public void randomLeafs(int howMany)
    {
        for(int i=0; i<howMany; i++) {
            Leaf leaf = new Leaf();
            int x = 15+Greenfoot.getRandomNumber(getWidth()-30);
            int y = 60+Greenfoot.getRandomNumber(getHeight()-75);
            addObject(leaf, x, y);
        }
    }
    
}